==> libjo_01_04.tar.gz: var/www/libjo/libjo.r37/smarty_dir/templates_c/%%5A^5AC^5AC62717%%index_login.tpl.php <==
<?php /* Smarty version 2.6.20, created on 2009-01-04 16:12:02
         compiled from index_login.tpl */ ?>
<div id="column2_main">
		
		<div id="index">
			<p> 781実習室図書管理システムへようこそ </p>
			
<div id="index_search_login">
		<div id="left_column">
		<span class="small_font"> 本のタイトルを入力してください </span>
<form action="book_search.php" method="GET">
		
		
			<input  type="text" name="name" class="search"  value="" /> <br />
			
	    	<label>
	    	<div class="div_left"><input type="submit" class="submit"  value="検索" /> </div>
	    	<input type="hidden" name="switch" value="on" />
		<input type="hidden" name="pagenumber" value="1" />
		</label>
</form>
		
<form action="book_search.php" method="GET">		
		
		<input type="submit"  value="一覧" /> 
		<input type="hidden" name="switch" value="all" />
		<input type="hidden" name="pagenumber" value="1" />
		<input type="hidden" name="category" value="すべての本">
		</form> </div> 		</div> 		



		<div id="right_column">

		<h3> 鈴木将之さんの借りている本	</h3>
		
		<table border=3px>
		<tr> 
			<th> タイトル </th>	<th>返却期限</th> <th>返却する</th>
		</tr>
		
		<?php unset($this->_sections['i']);
$this->_sections['i']['name'] = 'i';
$this->_sections['i']['loop'] = is_array($_loop=1) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['i']['show'] = true;
$this->_sections['i']['max'] = $this->_sections['i']['loop'];
$this->_sections['i']['step'] = 1;
$this->_sections['i']['start'] = $this->_sections['i']['step'] > 0 ? 0 : $this->_sections['i']['loop']-1;
if ($this->_sections['i']['show']) {
    $this->_sections['i']['total'] = $this->_sections['i']['loop'];
    if ($this->_sections['i']['total'] == 0)
        $this->_sections['i']['show'] = false;
} else
    $this->_sections['i']['total'] = 0;
if ($this->_sections['i']['show']):

            for ($this->_sections['i']['index'] = $this->_sections['i']['start'], $this->_sections['i']['iteration'] = 1;
                 $this->_sections['i']['iteration'] <= $this->_sections['i']['total'];
                 $this->_sections['i']['index'] += $this->_sections['i']['step'], $this->_sections['i']['iteration']++):
$this->_sections['i']['rownum'] = $this->_sections['i']['iteration'];
$this->_sections['i']['index_prev'] = $this->_sections['i']['index'] - $this->_sections['i']['step'];
$this->_sections['i']['index_next'] = $this->_sections['i']['index'] + $this->_sections['i']['step'];
$this->_sections['i']['first']      = ($this->_sections['i']['iteration'] == 1);
$this->_sections['i']['last']       = ($this->_sections['i']['iteration'] == $this->_sections['i']['total']);
?>
		<form action="return1.php?name=Fast CakePHP" method="GET">
		<tr>
			<td> <a href="book_info.php?name=<?php echo $this->_tpl_vars['book_date']['title']; ?>
"> <?php echo $this->_tpl_vars['book_date']['title']; ?>
 </a> </td>		<td><?php echo $this->_tpl_vars['book_date']['limit']; ?>
</td> 
		
			<td> <input type="submit" value="返却する"> </td>
		</tr>
		</form>
		<?php endfor; endif; ?>
		</table>
		</div> 
	</div>

==> libjo_12_29.tar.gz: var/www/libjo/libjo.r37/smarty_dir/templates_c/%%5A^5AC^5AC62717%%index_login.tpl.php <==
<?php /* Smarty version 2.6.20, created on 2008-12-29 17:21:28
         compiled from index_login.tpl */ ?>
<div id="column2_main">
		
		<div id="index">
			<p> 781実習室図書管理システムへようこそ </p>
			
<div id="index_search_login">
		<div id="left_column">
		<span class="small_font"> 本のタイトルを入力してください </span>
<form action="book_search.php" method="GET">
		
		
			<input  type="text" name="name" class="search"  value="" /> <br />
			
	    	<label>
	    	<div class="div_left"><input type="submit" class="submit" name="Submit" value="検索" /> </div>
	    	<input type="hidden" name="switch" value="on" />
		</label>
</form>
		
<form action="book_search.php" method="GET">		
		
		<input type="submit" class="submit" value="一覧" /> 
		<input type="hidden" name="switch" value="all" />

		</form> </div> 		</div> 		



		<div id="right_column">

		<h3> 鈴木将之さんの借りている本	</h3>
		
		<table border=3px>
		<tr> 
			<th> タイトル </th>	<th>返却期限</th> <th>返却する</th>
		</tr>
		
		<?php unset($this->_sections['i']);
$this->_sections['i']['name'] = 'i';
$this->_sections['i']['loop'] = is_array($_loop=1) ? count($_loop) : max(0, (int)$_loop); unset($_loop);
$this->_sections['i']['show'] = true;
$this->_sections['i']['max'] = $this->_sections['i']['loop'];
$this->_sections['i']['step'] = 1;
$this->_sections['i']['start'] = $this->_sections['i']['step'] > 0 ? 0 : $this->_sections['i']['loop']-1;
if ($this->_sections['i']['show']) {
    $this->_sections['i']['total'] = $this->_sections['i']['loop'];
    if ($this->_sections['i']['total'] == 0)
        $this->_sections['i']['show'] = false;
} else
    $this->_sections['i']['total'] = 0;
if ($this->_sections['i']['show']):

            for ($this->_sections['i']['index'] = $this->_sections['i']['start'], $this->_sections['i']['iteration'] = 1;
                 $this->_sections['i']['iteration'] <= $this->_sections['i']['total'];
                 $this->_sections['i']['index'] += $this->_sections['i']['step'], $this->_sections['i']['iteration']++):
$this->_sections['i']['rownum'] = $this->_sections['i']['iteration'];
$this->_sections['i']['index_prev'] = $this->_sections['i']['index'] - $this->_sections['i']['step'];
$this->_sections['i']['index_next'] = $this->_sections['i']['index'] + $this->_sections['i']['step'];
$this->_sections['i']['first']      = ($this->_sections['i']['iteration'] == 1);
$this->_sections['i']['last']       = ($this->_sections['i']['iteration'] == $this->_sections['i']['total']);
?>
		<form action="return1.php?name=Fast CakePHP" method="GET">
		<tr>
			<td> <a href="book_info.php?name=<?php echo $this->_tpl_vars['book_date']['title']; ?>
"> <?php echo $this->_tpl_vars['book_date']['title']; ?>
 </a> </td>		<td><?php echo $this->_tpl_vars['book_date']['limit']; ?>
</td> 
		
			<td> <input type="submit" value="返却する"> </td>
		</tr>
		</form>
		<?php endfor; endif; ?>
		</table>
		</div> 
	</div>
